@@ -1,5 +1,5 @@
 package App::Colorist::Colorizer;
-$App::Colorist::Colorizer::VERSION = '0.142540';
+$App::Colorist::Colorizer::VERSION = '0.150460';
 use Moose;
 
 use Carp;
@@ -409,19 +409,19 @@ sub readline {
 
             # Read it until we run out of input or until we hit at least one newline
             my ($eof, $buffer);
-            do {
+            READ: while (!defined $eof || ($eof != 0 && $line !~ /\n/)) {
                 $eof = sysread($fh, $buffer, 1024);
                 if (not defined $eof) {
                     if ($! == POSIX::EAGAIN) {
                         select undef, undef, undef, 0.1;
-                        next;
+                        next READ;
                     }
                     else {
                         croak("Error while reading handle: $!");
                     }
                 }
                 $line .= $buffer;
-            } while ($eof != 0 && $line !~ /\n/);
+            }
 
             $s->remove($fh) if $eof == 0;
 
@@ -562,7 +562,7 @@ App::Colorist::Colorizer - the brain behind App::Colorist
 
 =head1 VERSION
 
-version 0.142540
+version 0.150460
 
 =head1 SYNOPSIS
 
@@ -750,7 +750,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
